# Appliance dumps

|                                                                                  | Asko dishwasher   | Gorenje dishwasher   | Asko hood 1         | Asko hood 2         | Asko induction hob 1   | Asko induction hob 2   | Oven type 1         | Oven type 2          | Asko professional washing machine   | Gorenje washing machine   | Asko professional tumble dryer   | Heat pump        |
|:---------------------------------------------------------------------------------|:------------------|:---------------------|:--------------------|:--------------------|:-----------------------|:-----------------------|:--------------------|:---------------------|:------------------------------------|:--------------------------|:---------------------------------|:-----------------|
| bindTime                                                                         | 1668542674215     | 1710363016042        | 1711489190532       | 1629724970364       | 1637753665912          | 1629723678408          | 1652967068476       | 1711555870240        | 1634119536189                       | 1685083566362             | 1614938571640                    | 1693922922378    |
| createTime                                                                       | 0                 | 0                    | 0                   | 0                   | 0                      | 0                      | 0                   | 0                    | 0                                   | 0                         | 0                                | 0                |
| deviceFeatureCode                                                                | 000               | 000                  | 000                 | df8ae1406f86cade    | 000                    | 63c45b513e1a4bf7       | 295608422d362be1    | 000                  | 000                                 | 000                       | 000                              | 502              |
| deviceFeatureName                                                                | W-DW50/60-22      | W-DW50/60-22         | ConnectlifeHOOD     | HOOD                | H-PIND-18              | HOB                    | OVEN                | ConnectlifeOVEN      | ASKO Pro Washing Machine            | W-WaveEn-22               | ASKO Pro Dryer                   | 502自研热水器    |
| deviceId                                                                         | <redacted>        | <redacted>           | <redacted>          | <redacted>          | <redacted>             | <redacted>             | <redacted>          | <redacted>           | <redacted>                          | <redacted>                | <redacted>                       | <redacted>       |
| deviceNickName                                                                   | Oppvaskmaskin     | Dishwasher           | Hood                | Atos hood           | pind                   | Atag hob               | Atag Oven           | BIO 21               | wm Andrej                           | 015                       | TD Aandrej                       | Heat pump        |
| deviceTypeCode                                                                   | 015               | 015                  | 012                 | 021                 | 010                    | 020                    | 023                 | 013                  | 003                                 | 027                       | 004                              | 016              |
| deviceTypeName                                                                   |                   |                      |                     |                     | \u7f51\u5173           |                        |                     |                      |                                     |                           | ASKO Pro Dryer                   |                  |
| offlineState                                                                     | 1                 | 1                    | 1                   | 0                   | 1                      | 1                      | 1                   | 1                    | 0                                   | 0                         | 1                                | 1                |
| puid                                                                             | <redacted>        | <redacted>           | <redacted>          | <redacted>          | <redacted>             | <redacted>             | <redacted>          | <redacted>           | <redacted>                          | <redacted>                | <redacted>                       | <redacted>       |
| role                                                                             | 1                 | 1                    | 1                   | 1                   | 1                      | 1                      | 1                   | 2                    | 1                                   | 2                         | 1                                | 1                |
| roomId                                                                           | 1044366           | 3813850              | 142500              | 142500              | 145444                 | 142500                 | 144011              | 106345               | 106345                              | 106345                    | 106345                           | 2716250          |
| roomName                                                                         | Kjøkken           | default_room         | AR kitchen          | AR kitchen          | CES 2022               | AR kitchen             | cap lab             | default_room         | default_room                        | default_room              | default_room                     | default_room     |
| seq                                                                              | 0                 | 0                    | 0                   | 0                   | 0                      | 0                      | 0                   | 0                    | 0                                   | 0                         | 0                                | 0                |
| statusList.ACTION                                                                |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.ADO_allowed                                                           | 1                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.ADS_Dirtiness_setting_status                                          |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.ADS_Settings_Current_Program_Detergent_setting_status                 |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.ADS_Settings_Current_Program_Softener_setting_status                  |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.ActiveModeLightBrightness                                             |                   |                      | 0                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.ActiveModeLightColorTemperature                                       |                   |                      | 0                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.ActiveModeLightStatus                                                 |                   |                      | 2                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.ActiveModeMotorLevel                                                  |                   |                      | 1                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.ActiveModeMotorLevelStatus                                            |                   |                      | 2                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.ActiveModeStatus                                                      |                   |                      | 2                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Adapt_sense_setting_status                                            |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 2                         |                                  |                  |
| statusList.Adaptive_sense_setting                                                |                   |                      |                     |                     |                        |                        |                     | 1                    |                                     |                           |                                  |                  |
| statusList.AddClothes                                                            |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           |                                  |                  |
| statusList.Add_moist_now                                                         |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Add_on_program_download_ID                                            |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Add_on_program_download_status                                        |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Add_program_to_device                                                 |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Air_dry_function                                                      |                   |                      |                     |                     | 2                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Air_dry_function_status                                               |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Air_shower_setting_status                                             |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.AlarmAlmost_finished                                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AlarmChild_lockOff                                                    |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AlarmChild_lockOn                                                     |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AlarmCleanAirEnded                                                    |                   |                      | 1                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.AlarmCleanCondense                                                    |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.AlarmCleanCondenserFilter                                             |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.AlarmCleanDoorFilter                                                  |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.AlarmCleanFilterWarning                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.AlarmCleanTank                                                        |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AlarmCloseTheDoorWarning                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.AlarmDehydrate_ended                                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AlarmDemo_activated                                                   |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AlarmDescaleStep1                                                     |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AlarmDescaleStep2                                                     |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AlarmDescaleStep3                                                     |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AlarmDescaling_interrupted                                            |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AlarmEmptyTankPause                                                   |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AlarmFillAdContainer1Warning                                          |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.AlarmFillAdContainer2Warning                                          |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.AlarmFillTank                                                         |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AlarmFoamDetection                                                    |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.AlarmFullTank                                                         |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.AlarmGreaseFilter                                                     |                   |                      | 1                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.AlarmIncreased_power_consumption                                      |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AlarmKey_lock_on                                                      |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AlarmMicrowave_system_finished                                        |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AlarmOptionNotAvailable                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.AlarmOven_system_finished                                             |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AlarmPopTankOpened                                                    |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AlarmPowerFail                                                        |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.AlarmPowerFailAlert                                                   |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.AlarmPower_failure_running                                            |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AlarmProbe_lost_connection                                            |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AlarmProgramFinished                                                  |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.AlarmRecirculationFilter1                                             |                   |                      | 1                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.AlarmRecirculationFilter2                                             |                   |                      | 1                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.AlarmRemoteStartPowerFailure                                          |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AlarmRemove_probe                                                     |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AlarmSabbathAboutToStart                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AlarmSabbathEnded                                                     |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AlarmSabbathPostpone                                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AlarmSteamClean_finished                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AlarmSteam_interrupted                                                |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AlarmSteam_system_finished                                            |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AlarmSteriltubRunWarning                                              |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.AlarmTankLevel1                                                       |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AlarmTimerEnded                                                       |                   |                      | 1                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.AlarmWashFinished                                                     |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Alarm_1                                                               |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Alarm_10                                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Alarm_11                                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Alarm_12                                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Alarm_13                                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Alarm_14                                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Alarm_15                                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Alarm_16                                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Alarm_17                                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Alarm_18                                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Alarm_19                                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Alarm_2                                                               |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Alarm_20                                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Alarm_21                                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Alarm_22                                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Alarm_3                                                               |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Alarm_4                                                               |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Alarm_5                                                               |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Alarm_6                                                               |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Alarm_7                                                               |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Alarm_8                                                               |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Alarm_9                                                               |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Alarm_Grease_filter                                                   |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Alarm_Hob_Hood_Started                                                |                   |                      |                     |                     |                        | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.Alarm_NTC_TC                                                          |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.Alarm_NTC_coil_overheating                                            |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.Alarm_NTC_power                                                       |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.Alarm_Recirculation_filter_1                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Alarm_alarm_time_reached                                              |                   |                      |                     |                     |                        |                        | 0                   |                      |                                     |                           |                                  |                  |
| statusList.Alarm_aquaClean_finished                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Alarm_auto_dose_refill                                                | 1                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Alarm_auto_program_ended                                              |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Alarm_auto_program_notification                                       |                   |                      |                     |                     |                        | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.Alarm_automatic_switch_off_zone                                       |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.Alarm_baking_finished                                                 |                   |                      |                     |                     |                        |                        | 0                   | 1                    |                                     |                           |                                  |                  |
| statusList.Alarm_baking_stoped                                                   |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Alarm_child_lock_deactivated_on_the_oven                              |                   |                      |                     |                     |                        |                        |                     | 1                    |                                     |                           |                                  |                  |
| statusList.Alarm_clean_the_filters                                               | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Alarm_cleaning_suggestion_after_baking_finished                       |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Alarm_defrost_finished                                                |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Alarm_descale_now                                                     |                   |                      |                     |                     |                        |                        | 0                   |                      |                                     |                           |                                  |                  |
| statusList.Alarm_descaling_needed                                                |                   |                      |                     |                     |                        |                        |                     | 1                    |                                     |                           |                                  |                  |
| statusList.Alarm_door_closed                                                     | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Alarm_door_locked                                                     |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Alarm_door_opened                                                     | 1                 | 1                    |                     |                     |                        |                        |                     | 1                    |                                     |                           |                                  |                  |
| statusList.Alarm_ean_scan_info                                                   |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Alarm_empty_and_clean_water_tank                                      |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Alarm_fast_preheat_active                                             |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Alarm_fast_preheating_finished                                        |                   |                      |                     |                     |                        |                        |                     | 1                    |                                     |                           |                                  |                  |
| statusList.Alarm_grease_filter                                                   |                   |                      |                     | 0                   |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Alarm_hob_hood_started                                                |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Alarm_keepWarm_ended                                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Alarm_mw_active                                                       |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Alarm_oven_temperature_too_high                                       |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Alarm_oven_usage_reached_set_limit_auto_cleaning_suggested            |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Alarm_plateWarm_ended                                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Alarm_preheat_reached                                                 |                   |                      |                     |                     |                        |                        | 0                   |                      |                                     |                           |                                  |                  |
| statusList.Alarm_preheating_ready                                                | 0                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Alarm_probe_inserted                                                  |                   |                      |                     |                     |                        |                        |                     | 1                    |                                     |                           |                                  |                  |
| statusList.Alarm_probe_temp_reached                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Alarm_program_done                                                    | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Alarm_program_pause                                                   | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Alarm_pyrolytic_finished                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Alarm_recirculation_filter1                                           |                   |                      |                     | 0                   |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Alarm_remote_start_canceled                                           | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Alarm_rinse_aid_refill                                                | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Alarm_run_selfcleaning                                                | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Alarm_running_time_over_10_or_24_hour_limit_error                     |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Alarm_sabbath_reminder                                                |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Alarm_salt_refill                                                     | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Alarm_sand_timer_1_elapsed                                            |                   |                      |                     |                     |                        |                        |                     | 1                    |                                     |                           |                                  |                  |
| statusList.Alarm_sand_timer_2_elapsed                                            |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Alarm_sand_timer_3_elapsed                                            |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Alarm_set_temperature_reached                                         |                   |                      |                     |                     |                        |                        |                     | 1                    |                                     |                           |                                  |                  |
| statusList.Alarm_steam_empty                                                     |                   |                      |                     |                     |                        |                        | 0                   |                      |                                     |                           |                                  |                  |
| statusList.Alarm_steam_fill_alarm                                                |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Alarm_steam_function_active                                           |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Alarm_temperature_reached                                             |                   |                      |                     |                     |                        |                        | 0                   |                      |                                     |                           |                                  |                  |
| statusList.Alarm_timer_ended                                                     |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.Alarm_turn_food                                                       |                   |                      |                     |                     |                        |                        | 0                   | 0                    |                                     |                           |                                  |                  |
| statusList.Alarm_user_interaction_on_appliance_detected                          |                   |                      |                     |                     |                        |                        |                     | 1                    |                                     |                           |                                  |                  |
| statusList.Alarm_voltage                                                         |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.Alarm_warning_fastpreheat                                             |                   |                      |                     |                     |                        |                        | 0                   |                      |                                     |                           |                                  |                  |
| statusList.Alarm_warning_microwave                                               |                   |                      |                     |                     |                        |                        | 0                   |                      |                                     |                           |                                  |                  |
| statusList.Alarm_warning_steam                                                   |                   |                      |                     |                     |                        |                        | 0                   |                      |                                     |                           |                                  |                  |
| statusList.Alarm_water_tank_empty                                                |                   |                      |                     |                     |                        |                        | 0                   |                      |                                     |                           |                                  |                  |
| statusList.Alarm_water_tank_is_empty                                             |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Alarm_water_tank_is_missing                                           |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Alarm_water_tank_missing                                              |                   |                      |                     |                     |                        |                        | 0                   |                      |                                     |                           |                                  |                  |
| statusList.Alarm_zone_turned_off                                                 |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.AllergyModeEnable                                                     |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Almost_finished_notification_setting                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Almost_finished_notification_settingTimer_in_minutes                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AlramEmptyWaterTank                                                   |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.AmbientLightBrightness                                                |                   |                      | 0                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.AmbientLightColorTemperature                                          |                   |                      | 0                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.AmbientLightStatus                                                    |                   |                      | 0                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Ambient_sound_setting                                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Auto_Grease_filter_indication                                         |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Auto_Super_rinse_setting_status                                       |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Auto_Tower_Up                                                         |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Auto_boost                                                            |                   |                      |                     |                     | 1                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Auto_bridge                                                           |                   |                      |                     |                     | 1                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Auto_dose_Compartment1_amount_setting                                 |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Auto_dose_Compartment1_status_102                                     |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Auto_dose_Compartment1_tank_amount                                    |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 7                         |                                  |                  |
| statusList.Auto_dose_Compartment2_amount_setting                                 |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Auto_dose_Compartment2_status_102                                     |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Auto_dose_Compartment2_tank_amount                                    |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 3                         |                                  |                  |
| statusList.Auto_dose_drawer_status                                               |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Auto_dose_duration                                                    | 244               | 244                  |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Auto_dose_quantity_setting_status                                     | 3                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Auto_dose_refill                                                      | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Auto_dose_setting_status                                              | 2                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Auto_dose_system_setting_status                                       |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Auto_fast_preheat                                                     |                   |                      |                     |                     |                        |                        |                     | 1                    |                                     |                           |                                  |                  |
| statusList.Auto_timer                                                            |                   |                      |                     |                     | 1                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.AutomaticChild_lock_setting                                           |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AutomaticDoor_lock_setting                                            |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.AutomaticDoor_lock_setting_allowed                                    |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Automatic_display_brightness_setting                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Automatic_door_closing_at_program_start_setting                       |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Automatic_door_open_at_program_end_after_time_setting                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Automatic_door_open_at_program_end_after_time_settingTimer_in_minutes |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Automatic_door_open_at_program_end_setting                            |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Automatic_water_tank_opening_setting                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Bake_start_utc_datetime_bdc_timestamp                                 |                   |                      |                     |                     |                        |                        | 2024/5/8T11:8:55    |                      |                                     |                           |                                  |                  |
| statusList.Baking_start_time_hour                                                |                   |                      |                     |                     |                        |                        | 0                   |                      |                                     |                           |                                  |                  |
| statusList.Baking_start_time_minute                                              |                   |                      |                     |                     |                        |                        | 0                   |                      |                                     |                           |                                  |                  |
| statusList.Baking_steps_intensity_levels                                         |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Baking_steps_intensity_levels_type                                    |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.BlockDetailedProgramView                                              |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           | 1                                |                  |
| statusList.BookAvailableTime                                                     |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 9196                             |                  |
| statusList.BookReservedTime                                                      |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.BookTimeToEndReservation                                              |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 10                               |                  |
| statusList.Booking                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.Brand_splash_setting                                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Brightness                                                            |                   |                      |                     |                     |                        |                        |                     | 3                    | 2                                   |                           |                                  |                  |
| statusList.Brightness_setting                                                    |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.BuiltIn_Hood_status                                                   |                   |                      |                     |                     | 1                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.CURRENT_SET_STEP                                                      |                   |                      |                     |                     |                        |                        | 3162                |                      |                                     |                           |                                  |                  |
| statusList.CameraLive_feed_current_phase                                         |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.CameraLive_feed_status                                                |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.CameraPicture_current_phase                                           |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.CameraPicture_request                                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.CameraTime_lapse_current_phase                                        |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.CameraTime_lapse_request                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Camera_enable_setting                                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Camera_status                                                         |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Can_upload_WiFi_program                                               |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Chef_mode                                                             |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.ChildLockActive                                                       |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.ChildLockEnabled                                                      |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.Child_lock                                                            | 1                 | 0                    |                     |                     | 0                      | 8131                   | 3191                | 1                    |                                     |                           |                                  |                  |
| statusList.Child_lock_setting_status                                             | 1                 | 0                    |                     |                     |                        |                        |                     |                      |                                     | 2                         |                                  |                  |
| statusList.Child_lock_status_status                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.CirculationModeStatus                                                 |                   |                      | 1                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Circulation_mode                                                      |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Circulation_mode__set_flag                                            |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.CleanAirActivePassedHours                                             |                   |                      | 0                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.CleanAirActiveTotalHours                                              |                   |                      | 24                  |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.CleanAirDurationOfCycleInMinutes                                      |                   |                      | 10                  |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.CleanAirMotorLevel                                                    |                   |                      | 1                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.CleanAirRunCycleEveryNumberOfMinutes                                  |                   |                      | 0                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.CleanAirStartTime                                                     |                   |                      | 0002/11/30T00:00:00 |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.CleanAirStatus                                                        |                   |                      | 1                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.CleanCondenseFilter                                                   |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 10                               |                  |
| statusList.CleanDoorFilter                                                       |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 1                                |                  |
| statusList.Clean_air_active                                                      |                   |                      |                     | 6061                |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Clean_air_active_passed_hours                                         |                   |                      |                     | 0                   |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Clean_air_active_total_hours                                          |                   |                      |                     | 100                 |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Clean_air_duration_of_cycle_in_minutes                                |                   |                      |                     | 60                  |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Clean_air_motor_level                                                 |                   |                      |                     | 1                   |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.ColdWash                                                              |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Color_sensor_setting_status                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Compartment1_type_setting_status                                      |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Compartment2_type_setting_status                                      |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.CondenseWaterMode                                                     |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.CondenseWaterModeSet                                                  |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.Control_Response_Level                                                |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Cooking_intensity                                                     |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Crisp_function_available                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Crisp_function_status                                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Curent_program_duration                                               | 131               | 200                  |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Curent_program_remaining_time                                         | 86                | 65535                |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.CurrentProgramPhase                                                   |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.CurrentWaterTemperature                                               |                   |                      |                     |                     |                        |                        |                     |                      | 30                                  |                           |                                  |                  |
| statusList.Current_baking_step                                                   |                   |                      |                     |                     |                        |                        | 3252                | 2                    |                                     |                           |                                  |                  |
| statusList.Current_baking_step2                                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Current_program_phase                                                 | 7                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Current_temperature                                                   |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Current_washing_program_phase_2                                       |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Current_washing_program_phase_status                                  |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 15                        |                                  |                  |
| statusList.Current_water_level                                                   |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Darhcdq                                                               |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 65535                     |                                  |                  |
| statusList.Date_format_setting                                                   |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.DelayStartCountdownTimer                                              |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Delay_off_time                                                        |                   |                      |                     | 0                   |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Delay_start                                                           | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Delay_start_remaining_time                                            | 0                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Delay_start_remaining_time_in_minutes                                 |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 65535                     |                                  |                  |
| statusList.Delay_start_set_time                                                  | 0                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Delay_start_status                                                    |                   |                      |                     |                     |                        |                        | 0                   |                      |                                     |                           |                                  |                  |
| statusList.Delaystart_delayend_mode_status                                       |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Delaystart_delayend_remaining_time_in_minutes                         |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 65535                     |                                  |                  |
| statusList.Delaystart_delayend_timestamp_status                                  |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 16679/02/18T23:47:45      |                                  |                  |
| statusList.DemoMode                                                              |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.Demo_mode                                                             |                   |                      |                     |                     | 0                      |                        | 3296                | 1                    |                                     |                           |                                  |                  |
| statusList.Demo_mode_status                                                      | 0                 | 0                    |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Descale_status                                                        |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Detergent_amount_status                                               |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Detergent_indicator                                                   |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.DeviceStatus                                                          |                   |                      | 1                   |                     |                        |                        |                     |                      | 0                                   |                           | 6                                |                  |
| statusList.Device_status                                                         | 2                 | 1                    |                     | 6014                | 7                      | 8018                   | 3011                |                      |                                     |                           |                                  |                  |
| statusList.DisplayBrightness                                                     |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 2                                |                  |
| statusList.DisplayBrightness_setting                                             |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.DisplayContrast_setting                                               |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.DisplayLogo                                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 1                                |                  |
| statusList.Display_Brightness_setting_status                                     | 255               | 255                  |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Display_contrast_setting_status                                       | 3                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Display_logotype_setting_status                                       | 2                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Display_standby                                                       |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Display_switch_to_standby_after_minutes                               |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Door                                                                  |                   |                      |                     |                     |                        |                        | 3041                | 1                    |                                     |                           |                                  |                  |
| statusList.DoorStatus                                                            |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.Door_lock                                                             |                   |                      |                     |                     |                        |                        |                     | 2                    |                                     |                           |                                  |                  |
| statusList.Door_lock_status                                                      |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Door_open_notification_setting                                        |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Door_sensor_setting                                                   |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Door_status                                                           | 1                 | 2                    |                     |                     |                        |                        |                     |                      |                                     | 2                         |                                  |                  |
| statusList.Dose_assist_recommended_detergent_quantity_unit_status                |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Dose_assist_recommended_low_concenatration_detergent_quantity         |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 65535                     |                                  |                  |
| statusList.Dose_assist_status                                                    |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Drain                                                                 |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           |                                  |                  |
| statusList.DrumVleanProgramWarning                                               |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           |                                  |                  |
| statusList.Drum_light_setting_status                                             |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Duration_of_clock                                                     |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.ECO_mode                                                              |                   |                      |                     |                     | 0                      | 8202                   |                     |                      |                                     |                           |                                  |                  |
| statusList.Eco_mode_setting                                                      |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.EmptyWaterTank                                                        |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 1                                |                  |
| statusList.Energy_consumption_in_running_program                                 | 65535             | 65535                |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Energy_save_setting_status                                            | 0                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error0                                                                |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.Error1                                                                |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.Error10                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.Error11                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.Error12                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.Error12_1                                                             |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error12_10                                                            |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error12_12                                                            |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error12_2                                                             |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error12_3                                                             |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error12_4                                                             |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error12_5                                                             |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error12_6                                                             |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error12_7                                                             |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error12_8                                                             |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error12_9                                                             |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error13                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.Error13_1                                                             |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error13_2                                                             |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error13_3                                                             |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error14                                                               |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.Error15                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.Error2                                                                |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.Error22                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error23                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error24                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error25                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error26                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error27                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error28                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error29                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error3                                                                |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.Error30                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error31                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error32                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error33                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error34                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error35                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error36                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error37                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error38                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error39                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error4                                                                |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.Error40                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error41                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error42                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error43                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error44                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error45                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error46                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error47                                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error5                                                                |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.Error6                                                                |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.Error7                                                                |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.Error7_1                                                              |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Error8                                                                |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.Error9                                                                |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.Error_0                                                               |                   |                      |                     |                     |                        |                        |                     | 1                    |                                     | 1                         |                                  |                  |
| statusList.Error_1                                                               |                   |                      |                     |                     | 0                      |                        |                     | 1                    |                                     | 1                         |                                  |                  |
| statusList.Error_10                                                              |                   |                      |                     |                     | 0                      |                        |                     | 0                    |                                     | 1                         |                                  |                  |
| statusList.Error_11                                                              |                   |                      |                     |                     | 0                      |                        |                     | 0                    |                                     | 1                         |                                  |                  |
| statusList.Error_12                                                              |                   |                      |                     |                     | 0                      |                        |                     | 1                    |                                     | 1                         |                                  |                  |
| statusList.Error_12_1                                                            |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Error_12_10                                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Error_12_11                                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Error_12_12                                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Error_12_13                                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Error_12_14                                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Error_12_15                                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Error_12_16                                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Error_12_17                                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Error_12_18                                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Error_12_2                                                            |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Error_12_3                                                            |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Error_12_4                                                            |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Error_12_5                                                            |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Error_12_6                                                            |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Error_12_7                                                            |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Error_12_8                                                            |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Error_12_9                                                            |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Error_13                                                              |                   |                      |                     |                     |                        |                        |                     | 1                    |                                     | 1                         |                                  |                  |
| statusList.Error_13_1                                                            |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Error_13_2                                                            |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Error_13_3                                                            |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Error_14                                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     | 0                         |                                  |                  |
| statusList.Error_15                                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     | 1                         |                                  |                  |
| statusList.Error_16                                                              |                   |                      |                     |                     |                        |                        |                     | 1                    |                                     | 0                         |                                  |                  |
| statusList.Error_17                                                              |                   |                      |                     |                     |                        |                        |                     | 1                    |                                     | 0                         |                                  |                  |
| statusList.Error_18                                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     | 0                         |                                  |                  |
| statusList.Error_19                                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     | 0                         |                                  |                  |
| statusList.Error_2                                                               |                   |                      |                     |                     | 0                      |                        |                     | 0                    |                                     | 1                         |                                  |                  |
| statusList.Error_20                                                              |                   |                      |                     |                     |                        |                        |                     | 1                    |                                     | 0                         |                                  |                  |
| statusList.Error_21                                                              |                   |                      |                     |                     |                        |                        |                     | 1                    |                                     | 0                         |                                  |                  |
| statusList.Error_22                                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     | 1                         |                                  |                  |
| statusList.Error_23                                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     | 1                         |                                  |                  |
| statusList.Error_24                                                              |                   |                      |                     |                     |                        |                        |                     | 1                    |                                     | 0                         |                                  |                  |
| statusList.Error_25                                                              |                   |                      |                     |                     |                        |                        |                     | 1                    |                                     | 0                         |                                  |                  |
| statusList.Error_26                                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     | 0                         |                                  |                  |
| statusList.Error_27                                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     | 0                         |                                  |                  |
| statusList.Error_28                                                              |                   |                      |                     |                     |                        |                        |                     | 1                    |                                     | 0                         |                                  |                  |
| statusList.Error_29                                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     | 0                         |                                  |                  |
| statusList.Error_3                                                               |                   |                      |                     |                     | 0                      |                        |                     | 0                    |                                     | 1                         |                                  |                  |
| statusList.Error_30                                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     | 0                         |                                  |                  |
| statusList.Error_31                                                              |                   |                      |                     |                     |                        |                        |                     | 1                    |                                     | 0                         |                                  |                  |
| statusList.Error_32                                                              |                   |                      |                     |                     |                        |                        |                     | 1                    |                                     | 0                         |                                  |                  |
| statusList.Error_33                                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     | 0                         |                                  |                  |
| statusList.Error_34                                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     | 0                         |                                  |                  |
| statusList.Error_35                                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     | 0                         |                                  |                  |
| statusList.Error_36                                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     | 1                         |                                  |                  |
| statusList.Error_37                                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     | 1                         |                                  |                  |
| statusList.Error_38                                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     | 0                         |                                  |                  |
| statusList.Error_38_1                                                            |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Error_39                                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     | 0                         |                                  |                  |
| statusList.Error_4                                                               |                   |                      |                     |                     | 0                      |                        |                     | 1                    |                                     | 0                         |                                  |                  |
| statusList.Error_40                                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     | 1                         |                                  |                  |
| statusList.Error_41                                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Error_42                                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Error_43                                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Error_44                                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Error_45                                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Error_46                                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Error_47                                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Error_48                                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Error_49                                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Error_5                                                               |                   |                      |                     |                     | 0                      |                        |                     | 1                    |                                     | 0                         |                                  |                  |
| statusList.Error_50                                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Error_51                                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Error_52                                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Error_6                                                               |                   |                      |                     |                     | 0                      |                        |                     | 0                    |                                     | 1                         |                                  |                  |
| statusList.Error_7                                                               |                   |                      |                     |                     | 0                      |                        |                     | 0                    |                                     | 1                         |                                  |                  |
| statusList.Error_7_1                                                             |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Error_7_2                                                             |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Error_8                                                               |                   |                      |                     |                     | 0                      |                        |                     | 1                    |                                     | 1                         |                                  |                  |
| statusList.Error_89                                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Error_9                                                               |                   |                      |                     |                     | 0                      |                        |                     | 1                    |                                     | 1                         |                                  |                  |
| statusList.Error_90                                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Error_9_1                                                             |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Error_F70                                                             | 3                 | 2                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_F76                                                             | 1                 | 2                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_f10                                                             | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_f11                                                             | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_f12                                                             | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_f40                                                             | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_f41                                                             | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_f42                                                             | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_f43                                                             | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_f44                                                             | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_f45                                                             | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_f46                                                             | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_f52                                                             | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_f54                                                             | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_f56                                                             | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_f61                                                             | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_f62                                                             | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_f65                                                             | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_f67                                                             | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_f68                                                             | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_f69                                                             | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_f72                                                             | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_f74                                                             | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_f75                                                             | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_read_out_1_code                                                 | 12                | 255                  |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_read_out_1_cycle                                                | 475               | 65535                |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_read_out_1_status                                               | 1                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_read_out_2_code                                                 | 68                | 255                  |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_read_out_2_cycle                                                | 436               | 65535                |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_read_out_2_status                                               | 1                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_read_out_3_code                                                 | 65                | 255                  |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_read_out_3_cycle                                                | 0                 | 65535                |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Error_read_out_3_status                                               | 2                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.ExtraRinse                                                            |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Extra_rinse_status                                                    |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.FOTA_set                                                              |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.FOTA_set_flag                                                         |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.FOTA_status                                                           | 1                 | 5                    |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Factory_reset                                                         |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.FailureReadOut1                                                       |                   |                      |                     |                     |                        |                        |                     |                      | 3                                   |                           | 0                                |                  |
| statusList.FailureReadOut10                                                      |                   |                      |                     |                     |                        |                        |                     |                      | 3                                   |                           | 9                                |                  |
| statusList.FailureReadOut10LastCycle                                             |                   |                      |                     |                     |                        |                        |                     |                      | 2                                   |                           | 0                                |                  |
| statusList.FailureReadOut10NumberOfRepetiotion                                   |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.FailureReadOut11                                                      |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 10                               |                  |
| statusList.FailureReadOut11NumberOfRepetiotion                                   |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.FailureReadOut12                                                      |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 11                               |                  |
| statusList.FailureReadOut12NumberOfRepetiotion                                   |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 1                                |                  |
| statusList.FailureReadOut1LastCycle                                              |                   |                      |                     |                     |                        |                        |                     |                      | 18                                  |                           | 0                                |                  |
| statusList.FailureReadOut1NumberOfRepetiotion                                    |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.FailureReadOut2                                                       |                   |                      |                     |                     |                        |                        |                     |                      | 3                                   |                           | 1                                |                  |
| statusList.FailureReadOut2LastCycle                                              |                   |                      |                     |                     |                        |                        |                     |                      | 18                                  |                           | 0                                |                  |
| statusList.FailureReadOut2NumberOfRepetiotion                                    |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 1                                |                  |
| statusList.FailureReadOut3                                                       |                   |                      |                     |                     |                        |                        |                     |                      | 3                                   |                           | 2                                |                  |
| statusList.FailureReadOut3LastCycle                                              |                   |                      |                     |                     |                        |                        |                     |                      | 16                                  |                           | 0                                |                  |
| statusList.FailureReadOut3NumberOfRepetiotion                                    |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.FailureReadOut4                                                       |                   |                      |                     |                     |                        |                        |                     |                      | 3                                   |                           | 3                                |                  |
| statusList.FailureReadOut4LastCycle                                              |                   |                      |                     |                     |                        |                        |                     |                      | 13                                  |                           | 0                                |                  |
| statusList.FailureReadOut4NumberOfRepetiotion                                    |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.FailureReadOut5                                                       |                   |                      |                     |                     |                        |                        |                     |                      | 3                                   |                           | 4                                |                  |
| statusList.FailureReadOut5LastCycle                                              |                   |                      |                     |                     |                        |                        |                     |                      | 6                                   |                           | 0                                |                  |
| statusList.FailureReadOut5NumberOfRepetiotion                                    |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.FailureReadOut6                                                       |                   |                      |                     |                     |                        |                        |                     |                      | 3                                   |                           | 5                                |                  |
| statusList.FailureReadOut6LastCycle                                              |                   |                      |                     |                     |                        |                        |                     |                      | 5                                   |                           | 0                                |                  |
| statusList.FailureReadOut6NumberOfRepetiotion                                    |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 21                               |                  |
| statusList.FailureReadOut7                                                       |                   |                      |                     |                     |                        |                        |                     |                      | 3                                   |                           | 6                                |                  |
| statusList.FailureReadOut7LastCycle                                              |                   |                      |                     |                     |                        |                        |                     |                      | 4                                   |                           | 0                                |                  |
| statusList.FailureReadOut7NumberOfRepetiotion                                    |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.FailureReadOut8                                                       |                   |                      |                     |                     |                        |                        |                     |                      | 3                                   |                           | 7                                |                  |
| statusList.FailureReadOut8LastCycle                                              |                   |                      |                     |                     |                        |                        |                     |                      | 3                                   |                           | 0                                |                  |
| statusList.FailureReadOut8NumberOfRepetiotion                                    |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.FailureReadOut9                                                       |                   |                      |                     |                     |                        |                        |                     |                      | 3                                   |                           | 8                                |                  |
| statusList.FailureReadOut9LastCycle                                              |                   |                      |                     |                     |                        |                        |                     |                      | 2                                   |                           | 0                                |                  |
| statusList.FailureReadOut9NumberOfRepetiotion                                    |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.Fan_sequence_setting_status                                           | 2                 | 2                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Feedback_volumen_setting_status                                       | 3                 | 3                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Fill_salt                                                             | 1                 | 2                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Fota                                                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     | 4                         |                                  |                  |
| statusList.FotaStatus                                                            |                   |                      | 0                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Gratin_available                                                      |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Gratin_from_below_functionSet_time_in_seconds                         |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Gratin_from_below_function_allowed                                    |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Gratin_from_below_function_status                                     |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Gratin_function_Set_time_in_seconds                                   |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Gratin_status                                                         |                   |                      |                     |                     |                        |                        |                     | 1                    |                                     |                           |                                  |                  |
| statusList.Gratin_total_allowed_time_in_minutes                                  |                   |                      |                     |                     |                        |                        |                     | 30                   |                                     |                           |                                  |                  |
| statusList.Gratin_total_passed_time_in_minutes                                   |                   |                      |                     |                     |                        |                        |                     | 65535                |                                     |                           |                                  |                  |
| statusList.GreaseFilterCleaningIntervalInHours                                   |                   |                      | 30                  |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.GreaseFilterStatus                                                    |                   |                      | 2                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.GreaseFilterUsedHours                                                 |                   |                      | 23                  |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Grease_Filter_saturation                                              |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Grease_filter_cleaning_interval_in_hours                              |                   |                      |                     | 100                 | 64256                  |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Grease_filter_reset_counter                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Grease_filter_reset_counter_set_flag                                  |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Grease_filter_set_lifetime_in_hours                                   |                   |                      |                     | 100                 | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Grease_filter_set_lifetime_in_hours_set_flag                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Grease_filter_status                                                  |                   |                      |                     |                     | 3                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Grease_filter_timer_active                                            |                   |                      |                     | 6247                | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Grease_filter_timer_active_set_flag                                   |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Grease_filter_used_hours                                              |                   |                      |                     | 100                 | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Grill_plate_measured_temperature                                      |                   |                      |                     |                     |                        |                        |                     | 4484                 |                                     |                           |                                  |                  |
| statusList.Grill_plate_status                                                    |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.HOB_warming_zone_power_level                                          |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.HOB_warming_zone_status                                               |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.HardPairingStatus                                                     | 0                 | 0                    | 0                   |                     | 0                      |                        |                     | 0                    | 0                                   | 0                         | 0                                |                  |
| statusList.HardPairingUnpairAll                                                  |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Hard_pairing_status                                                   |                   |                      |                     | 9106                |                        |                        | 9106                |                      |                                     |                           |                                  |                  |
| statusList.Hard_pairing_unpair_all_set_flag                                      |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Heat_pump_setting_status                                              | 0                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Heater2Enable                                                         |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.HeatingSteps                                                          |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           |                                  |                  |
| statusList.Hide_setting                                                          |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.High_temperature_status                                               | 0                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Hob_status                                                            |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Hob_zone_1_status                                                     |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Hob_zone_2_status                                                     |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Hob_zone_3_status                                                     |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Hob_zone_4_status                                                     |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Hob_zone_5_status                                                     |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Hood_connected_via_RF                                                 |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Hood_fan_speed                                                        |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Hood_light                                                            |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Hood_status                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Hood_total_used_hours                                                 |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.HumiditySensor                                                        |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.IDCode                                                                |                   |                      |                     |                     |                        |                        |                     |                      | 230                                 |                           |                                  |                  |
| statusList.IDMachine                                                             |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 2673                             |                  |
| statusList.Identified                                                            |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.Inactivity_timeout                                                    |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Interior_Light_Control_available                                      |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Interior_light                                                        |                   |                      |                     |                     |                        |                        |                     | 1                    |                                     |                           |                                  |                  |
| statusList.Interior_light_at_power_off_setting_status                            | 2                 | 2                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Interior_light_status                                                 | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Key_sensitivity_level                                                 |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Key_sound                                                             |                   |                      |                     |                     |                        |                        |                     | 2                    |                                     |                           |                                  |                  |
| statusList.Key_sound_level                                                       |                   |                      |                     |                     | 3                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Language                                                              |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 16                               |                  |
| statusList.Language_setting                                                      |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Language_status                                                       | 4                 | 0                    |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Last_run_program_id                                                   | 255               | 255                  |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Light                                                                 |                   |                      |                     |                     |                        |                        | 3036                |                      |                                     |                           |                                  |                  |
| statusList.LightBrightness                                                       |                   |                      | 75                  |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.LightColorTemperature                                                 |                   |                      | 49                  |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.LightStatus                                                           |                   |                      | 1                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Light_brightness                                                      |                   |                      |                     | 100                 |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Light_color_temperature                                               |                   |                      |                     | 0                   |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Light_status                                                          |                   |                      |                     | 1                   |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.LightsBrightness_setting                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.LightsColor_temperature_setting                                       |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Lights_duration_setting                                               |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Liquid_unit_setting_status                                            |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Load                                                                  |                   |                      |                     |                     |                        |                        |                     |                      | 3                                   |                           |                                  |                  |
| statusList.LockPIN_code                                                          |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Logo                                                                  |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           |                                  |                  |
| statusList.Logo_setting_status                                                   |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 3                         |                                  |                  |
| statusList.MDO_on_demand                                                         | 0                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.MDO_on_demand_allowed                                                 | 0                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.MaxTimeEvent                                                          |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Max_RPM_allowed_stat                                                  |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Maximum_motor_level                                                   |                   |                      |                     | 5                   |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Meat_probe_measured_temperature                                       |                   |                      |                     |                     |                        |                        | 0                   | 65535                |                                     |                           |                                  |                  |
| statusList.Meat_probe_set_temperature                                            |                   |                      |                     |                     |                        |                        | 0                   | 65535                |                                     |                           |                                  |                  |
| statusList.Meat_probe_status                                                     |                   |                      |                     |                     |                        |                        |                     | 1                    |                                     |                           |                                  |                  |
| statusList.Motor                                                                 |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.MotorLevel                                                            |                   |                      | 0                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.MotorSpeed1000RPMAvailable                                            |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           |                                  |                  |
| statusList.MotorSpeed100RPMAvailable                                             |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           |                                  |                  |
| statusList.MotorSpeed1100RPMAvailable                                            |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           |                                  |                  |
| statusList.MotorSpeed1200RPMAvailable                                            |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           |                                  |                  |
| statusList.MotorSpeed1300RPMAvailable                                            |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           |                                  |                  |
| statusList.MotorSpeed1400RPMAvailable                                            |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           |                                  |                  |
| statusList.MotorSpeed1500RPMAvailable                                            |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           |                                  |                  |
| statusList.MotorSpeed1600RPMAvailable                                            |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           |                                  |                  |
| statusList.MotorSpeed400RPMAvailable                                             |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           |                                  |                  |
| statusList.MotorSpeed500RPMAvailable                                             |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           |                                  |                  |
| statusList.MotorSpeed600RPMAvailable                                             |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           |                                  |                  |
| statusList.MotorSpeed800RPMAvailable                                             |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           |                                  |                  |
| statusList.MotorSpeed900RPMAvailable                                             |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           |                                  |                  |
| statusList.MotorSpeedNoDrainAvailable                                            |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           |                                  |                  |
| statusList.MotorSpeedNoSpinAvailable                                             |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           |                                  |                  |
| statusList.Motor_level                                                           |                   |                      |                     | 5                   | 85                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Navigation_sound_setting                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Night_modeDisplay_brightness_setting                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Night_modeLight_brightness_setting                                    |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Night_modeVolume_setting                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Night_mode_off_hour                                                   |                   |                      |                     |                     |                        |                        |                     | 255                  |                                     |                           |                                  |                  |
| statusList.Night_mode_off_minute                                                 |                   |                      |                     |                     |                        |                        |                     | 255                  |                                     |                           |                                  |                  |
| statusList.Night_mode_on_hour                                                    |                   |                      |                     |                     |                        |                        |                     | 255                  |                                     |                           |                                  |                  |
| statusList.Night_mode_on_minute                                                  |                   |                      |                     |                     |                        |                        |                     | 255                  |                                     |                           |                                  |                  |
| statusList.Night_mode_status                                                     |                   |                      |                     |                     |                        |                        |                     | 1                    |                                     |                           |                                  |                  |
| statusList.Night_start_setting_status_102                                        |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.No_sound_status                                                       |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Notification_pitch_sound_setting                                      |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Notification_sounds_volume_setting                                    |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Notification_volumen_setting_status                                   | 3                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Number_of_rinses                                                      |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Odor_control_setting                                                  | 1                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Oven_measured_temperature                                             |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Oven_temperature                                                      |                   |                      |                     |                     |                        |                        | 45                  |                      |                                     |                           |                                  |                  |
| statusList.Oven_temperature_unit                                                 |                   |                      |                     |                     |                        |                        |                     | 1                    |                                     |                           |                                  |                  |
| statusList.Oven_temperature_unit_setting                                         |                   |                      |                     |                     |                        |                        |                     | 1                    |                                     |                           |                                  |                  |
| statusList.Oven_usage_value_alarm_limit                                          |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Oven_usage_value_time_since_last_cleaning                             |                   |                      |                     |                     |                        |                        |                     | 65535                |                                     |                           |                                  |                  |
| statusList.PPUOnlineCoinSystem                                                   |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.PPURECIPSS                                                            |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           | 0                                |                  |
| statusList.PPUWashEnabled                                                        |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.PPUWashTable1Finished                                                 |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.PPUWashTable1PID                                                      |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.PPUWashTable1Time                                                     |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.PPUWashTable2Finished                                                 |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.PPUWashTable2PID                                                      |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.PPUWashTable2Time                                                     |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.PPUWashTable3Finished                                                 |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.PPUWashTable3PID                                                      |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.PPUWashTable3Time                                                     |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.PPUWashTable4Finished                                                 |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.PPUWashTable4PID                                                      |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.PPUWashTable4Time                                                     |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.PPUWashTable5Finished                                                 |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.PPUWashTable5PID                                                      |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.PPUWashTable5Time                                                     |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.PaidByCoinBox                                                         |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           |                                  |                  |
| statusList.PaidByCoinBoxOrEADBS                                                  |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.ParseLibVersion                                                       |                   |                      |                     |                     |                        |                        |                     |                      | 511108                              |                           | 500525                           |                  |
| statusList.PaymentEnabledTimer                                                   |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.PaymentSystem                                                         |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.Permanent_pot_detection                                               |                   |                      |                     |                     | 1                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Permanent_remote_start                                                |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Position_of_tower                                                     |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Power_save_status                                                     |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Preheat                                                               |                   |                      |                     |                     |                        |                        | 0                   |                      |                                     |                           |                                  |                  |
| statusList.Pressure_calibration_setting_status                                   | 11                | 16                   |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.ProgramOptionAnticrease                                               |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.ProgramOptionTimeStartDelayHour                                       |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.ProgramRemainingTime                                                  |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.ProgramTimesStartDelayHours                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.Program_settingsDefault                                               |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Program_settingsStart_key_duation_forMW                               |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.ProximitySensor                                                       |                   |                      | 2                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.ProximitySensorReactionTime                                           |                   |                      | 0                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.ProximitySensorSensitivity                                            |                   |                      | 0                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.ProximitySensorStatus                                                 |                   |                      | 2                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Proximity_sensor_setting                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Proximity_sensor_settingClose_user_detectedDisplay_change_to          |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Proximity_sensor_settingClose_user_detectedLight_change_to            |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Proximity_sensor_settingDistant_user_detectedDisplay_change_to        |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Proximity_sensor_settingDistant_user_detectedLight_change_to          |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.RFPairingStatus                                                       |                   |                      | 0                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.RecirculationFilter1LifetimeInHours                                   |                   |                      | 360                 |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.RecirculationFilter1Status                                            |                   |                      | 1                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.RecirculationFilter1Type                                              |                   |                      | 4                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.RecirculationFilter1UsedHours                                         |                   |                      | 0                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.RecirculationFilter2LifetimeInHours                                   |                   |                      | 0                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.RecirculationFilter2Status                                            |                   |                      | 1                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.RecirculationFilter2Type                                              |                   |                      | 1                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.RecirculationFilter2UsedHours                                         |                   |                      | 0                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Recirculation_filter1_set_lifetime_in_hours                           |                   |                      |                     | 2000                |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Recirculation_filter1_timer_active                                    |                   |                      |                     | 6252                |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Recirculation_filter1_type                                            |                   |                      |                     | 1                   |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Recirculation_filter1_used_hours                                      |                   |                      |                     | 127                 |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Recirculation_filter_1_lifetime_in_hours                              |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Recirculation_filter_1_reset_counter                                  |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Recirculation_filter_1_reset_counter_set_flag                         |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Recirculation_filter_1_set_lifetime_in_hours                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Recirculation_filter_1_set_lifetime_in_hours_set_flag                 |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Recirculation_filter_1_set_type                                       |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Recirculation_filter_1_set_type_set_flag                              |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Recirculation_filter_1_status                                         |                   |                      |                     |                     | 3                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Recirculation_filter_1_timer_active                                   |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Recirculation_filter_1_timer_active_set_flag                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Recirculation_filter_1_type                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Recirculation_filter_1_used_hours                                     |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Recovery                                                              |                   |                      |                     |                     | 1                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.RemoteControlMode                                                     |                   |                      |                     |                     |                        |                        |                     |                      | 2                                   |                           | 2                                |                  |
| statusList.RemoteControlMonitoringSetCommands                                    |                   |                      | 2                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.RemoteControlMonitoringSetCommandsActions                             |                   |                      | 0                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.RemoteSetControlEnabled                                               |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           |                                  |                  |
| statusList.RemoteStartDuration                                                   |                   |                      |                     |                     |                        |                        |                     |                      | 10                                  |                           | 10                               |                  |
| statusList.RemoteStartEnabled                                                    |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           | 1                                |                  |
| statusList.Remote_control_mode                                                   |                   |                      |                     | 1                   |                        |                        | 2                   |                      |                                     |                           |                                  |                  |
| statusList.Remote_control_mode_monitoring                                        |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Remote_control_monitoring                                             |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Remote_control_monitoring_set_commands                                | 2                 | 2                    |                     |                     |                        |                        |                     | 1                    |                                     | 1                         |                                  |                  |
| statusList.Remote_control_monitoring_set_commands_actions                        | 1                 | 1                    |                     |                     |                        |                        |                     | 0                    |                                     | 0                         |                                  |                  |
| statusList.Remote_controlmode                                                    |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Remove_moist_now                                                      |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Reset_to_default                                                      |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Rinse_aid_refill                                                      | 1                 | 2                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Rinse_aid_setting_status                                              | 3                 | 6                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL                                                                    |                   |                      |                     |                     |                        | 6                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Active_timer                                                      |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Alarm_NTC_coil                                                    |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Alarm_NTC_coil_overheating                                        |                   |                      |                     |                     |                        | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Alarm_auto_program_notification                                   |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Alarm_automatic_switch_off_zone                                   |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Alarm_timer_ended                                                 |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Alarm_zone_turned_off                                             |                   |                      |                     |                     | 1                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Bridge_function_active                                            |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Bridged_to_zone                                                   |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Cooking_method                                                    |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Function_status                                                   |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Functions                                                         |                   |                      |                     |                     | 0                      | 8166                   |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Hestan_Cue_Set_Temperature                                        |                   |                      |                     |                     | 30                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Hestan_Cue_Temperature                                            |                   |                      |                     |                     | 30                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Hestan_Cue_cookware_type                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Hestan_Cue_next_step_required_warning                             |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_NTC_sensor                                                        |                   |                      |                     |                     | 25                     | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Pot_detected                                                      |                   |                      |                     |                     | 0                      | 8127                   |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Power_level                                                       |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Power_level_max                                                   |                   |                      |                     |                     |                        | 13                     |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Residual_heat_signal                                              |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Sand_timer_UTC_start_time_hours                                   |                   |                      |                     |                     | 23                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Sand_timer_UTC_start_time_minutes                                 |                   |                      |                     |                     | 59                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Sand_timer_UTC_start_time_seconds                                 |                   |                      |                     |                     | 59                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Sand_timer_paused_total_seconds                                   |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Sand_timer_status                                                 |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Status                                                            |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Stopwatch_UTC_start_time_hours                                    |                   |                      |                     |                     | 23                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Stopwatch_UTC_start_time_minutes                                  |                   |                      |                     |                     | 59                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Stopwatch_UTC_start_time_seconds                                  |                   |                      |                     |                     | 59                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Stopwatch_paused_total_seconds                                    |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Stopwatch_status                                                  |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Temperature                                                       |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Timer_UTC_end_time_hours                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Timer_UTC_end_time_minutes                                        |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Timer_UTC_end_time_seconds                                        |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Timer_UTC_paused_hours                                            |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Timer_UTC_paused_minutes                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Timer_UTC_paused_seconds                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_Zone_shape                                                        |                   |                      |                     |                     |                        | 8344                   |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_error_1                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_error_10                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_error_11                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_error_12                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_error_13                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_error_14                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_error_15                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_error_16                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_error_17                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_error_2                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_error_3                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_error_4                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_error_5                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_error_6                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_error_7                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_error_8                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL1_error_9                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Active_timer                                                      |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Alarm_NTC_coil                                                    |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Alarm_NTC_coil_overheating                                        |                   |                      |                     |                     |                        | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Alarm_auto_program_notification                                   |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Alarm_automatic_switch_off_zone                                   |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Alarm_timer_ended                                                 |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Alarm_zone_turned_off                                             |                   |                      |                     |                     | 1                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Bridge_function_active                                            |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Bridged_to_zone                                                   |                   |                      |                     |                     | 1                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Cooking_method                                                    |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Function_status                                                   |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Functions                                                         |                   |                      |                     |                     | 0                      | 8166                   |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Hestan_Cue_Set_Temperature                                        |                   |                      |                     |                     | 30                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Hestan_Cue_Temperature                                            |                   |                      |                     |                     | 30                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Hestan_Cue_cookware_type                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Hestan_Cue_next_step_required_warning                             |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_NTC_sensor                                                        |                   |                      |                     |                     | 25                     | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Pot_detected                                                      |                   |                      |                     |                     | 0                      | 8127                   |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Power_level                                                       |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Power_level_max                                                   |                   |                      |                     |                     |                        | 13                     |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Residual_heat_signal                                              |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Sand_timer_UTC_start_time_hours                                   |                   |                      |                     |                     | 23                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Sand_timer_UTC_start_time_minutes                                 |                   |                      |                     |                     | 59                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Sand_timer_UTC_start_time_seconds                                 |                   |                      |                     |                     | 59                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Sand_timer_paused_total_seconds                                   |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Sand_timer_status                                                 |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Status                                                            |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Stopwatch_UTC_start_time_hours                                    |                   |                      |                     |                     | 23                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Stopwatch_UTC_start_time_minutes                                  |                   |                      |                     |                     | 59                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Stopwatch_UTC_start_time_seconds                                  |                   |                      |                     |                     | 59                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Stopwatch_paused_total_seconds                                    |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Stopwatch_status                                                  |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Temperature                                                       |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Timer_UTC_end_time_hours                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Timer_UTC_end_time_minutes                                        |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Timer_UTC_end_time_seconds                                        |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Timer_UTC_paused_hours                                            |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Timer_UTC_paused_minutes                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Timer_UTC_paused_seconds                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_Zone_shape                                                        |                   |                      |                     |                     |                        | 8344                   |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_error_1                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_error_10                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_error_11                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_error_12                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_error_13                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_error_14                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_error_15                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_error_16                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_error_17                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_error_2                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_error_3                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_error_4                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_error_5                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_error_6                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_error_7                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_error_8                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL2_error_9                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Active_timer                                                      |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Alarm_NTC_coil                                                    |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Alarm_NTC_coil_overheating                                        |                   |                      |                     |                     |                        | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Alarm_auto_program_notification                                   |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Alarm_automatic_switch_off_zone                                   |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Alarm_timer_ended                                                 |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Alarm_zone_turned_off                                             |                   |                      |                     |                     | 1                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Bridge_function_active                                            |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Bridged_to_zone                                                   |                   |                      |                     |                     | 2                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Cooking_method                                                    |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Function_status                                                   |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Functions                                                         |                   |                      |                     |                     | 0                      | 8166                   |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Hestan_Cue_Set_Temperature                                        |                   |                      |                     |                     | 30                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Hestan_Cue_Temperature                                            |                   |                      |                     |                     | 30                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Hestan_Cue_cookware_type                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Hestan_Cue_next_step_required_warning                             |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_NTC_sensor                                                        |                   |                      |                     |                     | 24                     | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Pot_detected                                                      |                   |                      |                     |                     | 1                      | 8127                   |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Power_level                                                       |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Power_level_max                                                   |                   |                      |                     |                     |                        | 13                     |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Residual_heat_signal                                              |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Sand_timer_UTC_start_time_hours                                   |                   |                      |                     |                     | 23                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Sand_timer_UTC_start_time_minutes                                 |                   |                      |                     |                     | 59                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Sand_timer_UTC_start_time_seconds                                 |                   |                      |                     |                     | 59                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Sand_timer_paused_total_seconds                                   |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Sand_timer_status                                                 |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Status                                                            |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Stopwatch_UTC_start_time_hours                                    |                   |                      |                     |                     | 23                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Stopwatch_UTC_start_time_minutes                                  |                   |                      |                     |                     | 59                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Stopwatch_UTC_start_time_seconds                                  |                   |                      |                     |                     | 59                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Stopwatch_paused_total_seconds                                    |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Stopwatch_status                                                  |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Temperature                                                       |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Timer_UTC_end_time_hours                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Timer_UTC_end_time_minutes                                        |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Timer_UTC_end_time_seconds                                        |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Timer_UTC_paused_hours                                            |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Timer_UTC_paused_minutes                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Timer_UTC_paused_seconds                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_Zone_shape                                                        |                   |                      |                     |                     |                        | 8341                   |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_error_1                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_error_10                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_error_11                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_error_12                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_error_13                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_error_14                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_error_15                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_error_16                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_error_17                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_error_2                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_error_3                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_error_4                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_error_5                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_error_6                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_error_7                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_error_8                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL3_error_9                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Active_timer                                                      |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Alarm_NTC_coil                                                    |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Alarm_NTC_coil_overheating                                        |                   |                      |                     |                     |                        | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Alarm_auto_program_notification                                   |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Alarm_automatic_switch_off_zone                                   |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Alarm_timer_ended                                                 |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Alarm_zone_turned_off                                             |                   |                      |                     |                     | 1                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Bridge_function_active                                            |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Bridged_to_zone                                                   |                   |                      |                     |                     | 3                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Cooking_method                                                    |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Function_status                                                   |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Functions                                                         |                   |                      |                     |                     | 0                      | 8166                   |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Hestan_Cue_Set_Temperature                                        |                   |                      |                     |                     | 30                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Hestan_Cue_Temperature                                            |                   |                      |                     |                     | 30                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Hestan_Cue_cookware_type                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Hestan_Cue_next_step_required_warning                             |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_NTC_sensor                                                        |                   |                      |                     |                     | 25                     | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Pot_detected                                                      |                   |                      |                     |                     | 0                      | 8127                   |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Power_level                                                       |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Power_level_max                                                   |                   |                      |                     |                     |                        | 13                     |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Residual_heat_signal                                              |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Sand_timer_UTC_start_time_hours                                   |                   |                      |                     |                     | 23                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Sand_timer_UTC_start_time_minutes                                 |                   |                      |                     |                     | 59                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Sand_timer_UTC_start_time_seconds                                 |                   |                      |                     |                     | 59                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Sand_timer_paused_total_seconds                                   |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Sand_timer_status                                                 |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Status                                                            |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Stopwatch_UTC_start_time_hours                                    |                   |                      |                     |                     | 23                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Stopwatch_UTC_start_time_minutes                                  |                   |                      |                     |                     | 59                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Stopwatch_UTC_start_time_seconds                                  |                   |                      |                     |                     | 59                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Stopwatch_paused_total_seconds                                    |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Stopwatch_status                                                  |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Temperature                                                       |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Timer_UTC_end_time_hours                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Timer_UTC_end_time_minutes                                        |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Timer_UTC_end_time_seconds                                        |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Timer_UTC_paused_hours                                            |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Timer_UTC_paused_minutes                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Timer_UTC_paused_seconds                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_Zone_shape                                                        |                   |                      |                     |                     |                        | 8344                   |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_error_1                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_error_10                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_error_11                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_error_12                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_error_13                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_error_14                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_error_15                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_error_16                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_error_17                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_error_2                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_error_3                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_error_4                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_error_5                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_error_6                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_error_7                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_error_8                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL4_error_9                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Active_timer                                                      |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Alarm_NTC_coil                                                    |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Alarm_NTC_coil_overheating                                        |                   |                      |                     |                     |                        | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Alarm_auto_program_notification                                   |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Alarm_automatic_switch_off_zone                                   |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Alarm_timer_ended                                                 |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Alarm_zone_turned_off                                             |                   |                      |                     |                     | 1                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Bridge_function_active                                            |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Bridged_to_zone                                                   |                   |                      |                     |                     | 4                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Cooking_method                                                    |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Function_status                                                   |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Functions                                                         |                   |                      |                     |                     | 0                      | 8166                   |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Hestan_Cue_Set_Temperature                                        |                   |                      |                     |                     | 30                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Hestan_Cue_Temperature                                            |                   |                      |                     |                     | 30                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Hestan_Cue_cookware_type                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Hestan_Cue_next_step_required_warning                             |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_NTC_sensor                                                        |                   |                      |                     |                     | 25                     | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Pot_detected                                                      |                   |                      |                     |                     | 0                      | 8127                   |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Power_level                                                       |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Power_level_max                                                   |                   |                      |                     |                     |                        | 13                     |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Residual_heat_signal                                              |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Sand_timer_UTC_start_time_hours                                   |                   |                      |                     |                     | 23                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Sand_timer_UTC_start_time_minutes                                 |                   |                      |                     |                     | 59                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Sand_timer_UTC_start_time_seconds                                 |                   |                      |                     |                     | 59                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Sand_timer_paused_total_seconds                                   |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Sand_timer_status                                                 |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Status                                                            |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Stopwatch_UTC_start_time_hours                                    |                   |                      |                     |                     | 23                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Stopwatch_UTC_start_time_minutes                                  |                   |                      |                     |                     | 59                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Stopwatch_UTC_start_time_seconds                                  |                   |                      |                     |                     | 59                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Stopwatch_paused_total_seconds                                    |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Stopwatch_status                                                  |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Temperature                                                       |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Timer_UTC_end_time_hours                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Timer_UTC_end_time_minutes                                        |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Timer_UTC_end_time_seconds                                        |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Timer_UTC_paused_hours                                            |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Timer_UTC_paused_minutes                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Timer_UTC_paused_seconds                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_Zone_shape                                                        |                   |                      |                     |                     |                        | 8344                   |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_error_1                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_error_10                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_error_11                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_error_12                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_error_13                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_error_14                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_error_15                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_error_16                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_error_17                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_error_2                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_error_3                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_error_4                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_error_5                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_error_6                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_error_7                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_error_8                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL5_error_9                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Active_timer                                                      |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Alarm_NTC_coil                                                    |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Alarm_NTC_coil_overheating                                        |                   |                      |                     |                     |                        | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Alarm_auto_program_notification                                   |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Alarm_automatic_switch_off_zone                                   |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Alarm_timer_ended                                                 |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Alarm_zone_turned_off                                             |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Bridge_function_active                                            |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Bridged_to_zone                                                   |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Cooking_method                                                    |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Function_status                                                   |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Functions                                                         |                   |                      |                     |                     | 0                      | 8166                   |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Hestan_Cue_Set_Temperature                                        |                   |                      |                     |                     | 30                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Hestan_Cue_Temperature                                            |                   |                      |                     |                     | 30                     |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Hestan_Cue_cookware_type                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Hestan_Cue_next_step_required_warning                             |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_NTC_sensor                                                        |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Pot_detected                                                      |                   |                      |                     |                     | 0                      | 8127                   |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Power_level                                                       |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Power_level_max                                                   |                   |                      |                     |                     |                        | 13                     |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Residual_heat_signal                                              |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Sand_timer_UTC_start_time_hours                                   |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Sand_timer_UTC_start_time_minutes                                 |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Sand_timer_UTC_start_time_seconds                                 |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Sand_timer_paused_total_seconds                                   |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Sand_timer_status                                                 |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Status                                                            |                   |                      |                     |                     | 0                      | 0                      |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Stopwatch_UTC_start_time_hours                                    |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Stopwatch_UTC_start_time_minutes                                  |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Stopwatch_UTC_start_time_seconds                                  |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Stopwatch_paused_total_seconds                                    |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Stopwatch_status                                                  |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Temperature                                                       |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Timer_UTC_end_time_hours                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Timer_UTC_end_time_minutes                                        |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Timer_UTC_end_time_seconds                                        |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Timer_UTC_paused_hours                                            |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Timer_UTC_paused_minutes                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Timer_UTC_paused_seconds                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_Zone_shape                                                        |                   |                      |                     |                     |                        | 8345                   |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_error_1                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_error_10                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_error_11                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_error_12                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_error_13                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_error_14                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_error_15                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_error_16                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_error_17                                                          |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_error_2                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_error_3                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_error_4                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_error_5                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_error_6                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_error_7                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_error_8                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SL6_error_9                                                           |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Sabbath_mode_setting                                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Sabbath_mode_settingBakingEnd_atHour                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Sabbath_mode_settingBakingEnd_atMinute                                |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Sabbath_mode_settingBakingStart_atHour                                |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Sabbath_mode_settingBakingStart_atMinute                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Sabbath_mode_settingCavity_light_during_sabbath                       |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Sabbath_mode_settingEnd_timeHour                                      |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Sabbath_mode_settingEnd_timeMinute                                    |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Sabbath_mode_settingSet_heater_system                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Sabbath_mode_settingStart_timeHour                                    |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Sabbath_mode_settingStart_timeMinute                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Sabbath_mode_setting_activate_weekly                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Sabbath_mode_status                                                   |                   |                      |                     |                     |                        |                        |                     | 1                    |                                     |                           |                                  |                  |
| statusList.Sand_timer1_duration_in_seconds                                       |                   |                      |                     |                     |                        |                        | 0                   |                      |                                     |                           |                                  |                  |
| statusList.Sand_timer1_start_utc_datetime_bdc_timestamp                          |                   |                      |                     |                     |                        |                        | 2024/1/24T14:50:59  |                      |                                     |                           |                                  |                  |
| statusList.Sand_timer1_status                                                    |                   |                      |                     |                     |                        |                        | 1                   |                      |                                     |                           |                                  |                  |
| statusList.Sand_timer2_duration_in_seconds                                       |                   |                      |                     |                     |                        |                        | 0                   |                      |                                     |                           |                                  |                  |
| statusList.Sand_timer2_start_utc_datetime_bdc_timestamp                          |                   |                      |                     |                     |                        |                        | 2023/12/13T11:34:47 |                      |                                     |                           |                                  |                  |
| statusList.Sand_timer2_status                                                    |                   |                      |                     |                     |                        |                        | 1                   |                      |                                     |                           |                                  |                  |
| statusList.Sand_timer3_duration_in_seconds                                       |                   |                      |                     |                     |                        |                        | 0                   |                      |                                     |                           |                                  |                  |
| statusList.Sand_timer3_start_utc_datetime_bdc_timestamp                          |                   |                      |                     |                     |                        |                        | 2023/12/13T11:35:2  |                      |                                     |                           |                                  |                  |
| statusList.Sand_timer3_status                                                    |                   |                      |                     |                     |                        |                        | 1                   |                      |                                     |                           |                                  |                  |
| statusList.Sand_timer_1_duration_hours                                           |                   |                      |                     |                     |                        |                        |                     | 255                  |                                     |                           |                                  |                  |
| statusList.Sand_timer_1_duration_minutes                                         |                   |                      |                     |                     |                        |                        |                     | 255                  |                                     |                           |                                  |                  |
| statusList.Sand_timer_1_duration_seconds                                         |                   |                      |                     |                     |                        |                        |                     | 255                  |                                     |                           |                                  |                  |
| statusList.Sand_timer_1_end_utc_datetime_bdc_timestamp                           |                   |                      |                     |                     |                        |                        |                     | 16679/02/18T23:47:45 |                                     |                           |                                  |                  |
| statusList.Sand_timer_1_paused_total_seconds                                     |                   |                      |                     |                     |                        |                        |                     | 65535                |                                     |                           |                                  |                  |
| statusList.Sand_timer_1_start_utc_datetime_bdc_timestamp                         |                   |                      |                     |                     |                        |                        |                     | 16679/02/18T23:47:45 |                                     |                           |                                  |                  |
| statusList.Sand_timer_1_status                                                   |                   |                      |                     |                     |                        |                        |                     | 5                    |                                     |                           |                                  |                  |
| statusList.Sand_timer_2_duration_hours                                           |                   |                      |                     |                     |                        |                        |                     | 255                  |                                     |                           |                                  |                  |
| statusList.Sand_timer_2_duration_minutes                                         |                   |                      |                     |                     |                        |                        |                     | 255                  |                                     |                           |                                  |                  |
| statusList.Sand_timer_2_duration_seconds                                         |                   |                      |                     |                     |                        |                        |                     | 255                  |                                     |                           |                                  |                  |
| statusList.Sand_timer_2_end_utc_datetime_bdc_timestamp                           |                   |                      |                     |                     |                        |                        |                     | 16679/02/18T23:47:45 |                                     |                           |                                  |                  |
| statusList.Sand_timer_2_paused_total_seconds                                     |                   |                      |                     |                     |                        |                        |                     | 65535                |                                     |                           |                                  |                  |
| statusList.Sand_timer_2_start_utc_datetime_bdc_timestamp                         |                   |                      |                     |                     |                        |                        |                     | 16679/02/18T23:47:45 |                                     |                           |                                  |                  |
| statusList.Sand_timer_2_status                                                   |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Sand_timer_3_duration_hours                                           |                   |                      |                     |                     |                        |                        |                     | 255                  |                                     |                           |                                  |                  |
| statusList.Sand_timer_3_duration_minutes                                         |                   |                      |                     |                     |                        |                        |                     | 255                  |                                     |                           |                                  |                  |
| statusList.Sand_timer_3_duration_seconds                                         |                   |                      |                     |                     |                        |                        |                     | 255                  |                                     |                           |                                  |                  |
| statusList.Sand_timer_3_end_utc_datetime_bdc_timestamp                           |                   |                      |                     |                     |                        |                        |                     | 16679/02/18T23:47:45 |                                     |                           |                                  |                  |
| statusList.Sand_timer_3_paused_total_seconds                                     |                   |                      |                     |                     |                        |                        |                     | 65535                |                                     |                           |                                  |                  |
| statusList.Sand_timer_3_start_utc_datetime_bdc_timestamp                         |                   |                      |                     |                     |                        |                        |                     | 16679/02/18T23:47:45 |                                     |                           |                                  |                  |
| statusList.Sand_timer_3_status                                                   |                   |                      |                     |                     |                        |                        |                     | 7                    |                                     |                           |                                  |                  |
| statusList.Sani_Lock                                                             | 3                 | 3                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Sani_Lock_allowed                                                     | 3                 | 3                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Scanned_EAN_code                                                      |                   |                      |                     |                     |                        |                        |                     | -12-500000000000     |                                     |                           |                                  |                  |
| statusList.SelectedBasicID                                                       |                   |                      |                     |                     |                        |                        |                     |                      | 54                                  |                           | 0                                |                  |
| statusList.SelectedDerivedID                                                     |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.SelectedProgram                                                       |                   |                      |                     |                     |                        |                        |                     |                      | 15                                  |                           | 0                                |                  |
| statusList.Selected_program_Disinfection                                         |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Selected_program_Eco_Disinfection                                     |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Selected_program_Eco_Green_mode                                       |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Selected_program_Eco_Small_load                                       |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Selected_program_Eco_Speed_mode                                       |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Selected_program_Green_leaves_AntiCrease                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Selected_program_Green_leaves_Entry_steam                             |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Selected_program_Green_leaves_Prewash                                 |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Selected_program_Intensive_mode                                       |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Selected_program_Lower_wash_function                                  | 0                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Selected_program_Night_mode                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Selected_program_Small_load_status                                    |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Selected_program_Super_rinse                                          |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Selected_program_Upper_wash_function                                  | 0                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Selected_program_Water_add                                            |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Selected_program_anticrease_status                                    |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Selected_program_auto_door_open_function                              | 2                 | 2                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Selected_program_dry_function                                         | 0                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Selected_program_duration_in_minutes                                  |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1023                      |                                  |                  |
| statusList.Selected_program_entry_steam_status                                   |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Selected_program_extra_drying_function                                | 0                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Selected_program_id_status                                            | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     | 255                       |                                  |                  |
| statusList.Selected_program_load_status                                          |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Selected_program_mode                                                 | 2                 | 2                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Selected_program_mode2_status                                         |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Selected_program_mode_status                                          |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Selected_program_prewash_status                                       |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Selected_program_remaining_time_in_minutes                            |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1023                      |                                  |                  |
| statusList.Selected_program_rinse_hold_status                                    |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Selected_program_set_temperature_status                               |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Selected_program_storage_function                                     | 0                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Selected_program_uv_function                                          | 0                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Selected_program_washing_spin_speed_rpm_status                        |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Selected_program_water_pluse_status                                   |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Sensor3D                                                              |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           |                                  |                  |
| statusList.SessionPairing                                                        |                   |                      | 0                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SessionPairingActive                                                  |                   |                      | 0                   |                     |                        |                        |                     |                      | 3                                   |                           | 3                                |                  |
| statusList.SessionPairingConfirmation                                            |                   |                      | 0                   |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.SessionPairingRequest                                                 |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.SessionPairingSetting                                                 |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           | 1                                |                  |
| statusList.Session_pairing_active                                                | 0                 | 0                    |                     |                     |                        |                        |                     | 0                    |                                     | 0                         |                                  |                  |
| statusList.Session_pairing_confirmation                                          | 0                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Session_pairing_setting                                               |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Session_pairing_status                                                | 0                 | 0                    |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.SetMaxMotorSpeed                                                      |                   |                      |                     |                     |                        |                        |                     |                      | 16                                  |                           |                                  |                  |
| statusList.Set_progress_type                                                     |                   |                      |                     |                     |                        |                        | 3401                |                      |                                     |                           |                                  |                  |
| statusList.Set_time_Hour                                                         |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Set_time_Minutes                                                      |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Settings_day                                                          |                   |                      |                     |                     |                        |                        |                     | 255                  |                                     |                           |                                  |                  |
| statusList.Settings_hour                                                         |                   |                      |                     |                     |                        |                        |                     | 16                   |                                     |                           |                                  |                  |
| statusList.Settings_minute                                                       |                   |                      |                     |                     |                        |                        |                     | 31                   |                                     |                           |                                  |                  |
| statusList.Settings_month                                                        |                   |                      |                     |                     |                        |                        |                     | 255                  |                                     |                           |                                  |                  |
| statusList.Settings_year                                                         |                   |                      |                     |                     |                        |                        |                     | 65535                |                                     |                           |                                  |                  |
| statusList.Shop_mode_setting                                                     |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.ShowMeasuredTemperature                                               |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Show_date_setting                                                     |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Silence_on_demand                                                     | 0                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Silence_on_demand_allowed                                             | 0                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Smart_sync_setting_status                                             |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.SoftPairing                                                           |                   |                      | 0                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SoftPairingSetting                                                    |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           | 1                                |                  |
| statusList.Soft_pairing_setting                                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Soft_pairing_status                                                   | 0                 | 0                    |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Softener_amount_status                                                |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Softener_indicator                                                    |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Sound                                                                 |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Sound_setting_status                                                  |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 3                         |                                  |                  |
| statusList.Speed_on_demand                                                       | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Spend_on_demand_allowed                                               | 3                 | 2                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SpinTime                                                              |                   |                      |                     |                     |                        |                        |                     |                      | 100                                 |                           |                                  |                  |
| statusList.Stage_lights_setting                                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Stain_program_Set_clothes_type_status                                 |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Stain_program_Set_stain_status                                        |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Stand_by_time                                                         |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.StandbyChoice                                                         |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 0                                |                  |
| statusList.StartDelayFunction                                                    |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           | 1                                |                  |
| statusList.Status                                                                |                   |                      |                     |                     |                        |                        | 3011                | 1                    |                                     | 0                         |                                  |                  |
| statusList.Steam123_0_available                                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Steam123_1_available                                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Steam123_2_available                                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Steam123_3_available                                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Steam_123                                                             |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Steam_assist_Time_used                                                |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Steam_reduction_at_door_opening_setting                               |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Steam_reduction_at_program_end_setting                                |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Steam_shot                                                            |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step1Add_moistStart_at_minute                                         |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step1Add_moistValve_open_percentage                                   |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step1Add_moist_status                                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step1Alarm_after_step                                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step1Grill_intensity                                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step1Pause_after_step                                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step1Remove_moistStart_at_minute                                      |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step1_Steam_assist                                                    |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step1_Steam_assistSet_time_in_minutes                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step1_Steam_assist_intensity                                          |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step1_duration                                                        |                   |                      |                     |                     |                        |                        | 30                  |                      |                                     |                           |                                  |                  |
| statusList.Step1_heater_system                                                   |                   |                      |                     |                     |                        |                        | 3081                |                      |                                     |                           |                                  |                  |
| statusList.Step1_remaining_time                                                  |                   |                      |                     |                     |                        |                        | 7                   |                      |                                     |                           |                                  |                  |
| statusList.Step1_setMulti_level_baking                                           |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step1_set_temperature                                                 |                   |                      |                     |                     |                        |                        | 180                 |                      |                                     |                           |                                  |                  |
| statusList.Step1_status                                                          |                   |                      |                     |                     |                        |                        | 0                   |                      |                                     |                           |                                  |                  |
| statusList.Step2Add_moistStart_at_minute                                         |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step2Add_moistValve_open_percentage                                   |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step2Add_moist_status                                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step2Alarm_after_step                                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step2Grill_intensity                                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step2Pause_after_step                                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step2Remove_moistStart_at_minute                                      |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step2_Steam_assist                                                    |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step2_Steam_assistSet_time_in_minutes                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step2_Steam_assist_intensity                                          |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step2_duration                                                        |                   |                      |                     |                     |                        |                        | 6                   |                      |                                     |                           |                                  |                  |
| statusList.Step2_heater_system                                                   |                   |                      |                     |                     |                        |                        | 3097                |                      |                                     |                           |                                  |                  |
| statusList.Step2_remaining_time                                                  |                   |                      |                     |                     |                        |                        | 3                   |                      |                                     |                           |                                  |                  |
| statusList.Step2_setMulti_level_baking                                           |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step2_set_temperature                                                 |                   |                      |                     |                     |                        |                        | 139                 |                      |                                     |                           |                                  |                  |
| statusList.Step2_status                                                          |                   |                      |                     |                     |                        |                        | 0                   |                      |                                     |                           |                                  |                  |
| statusList.Step3Add_moistStart_at_minute                                         |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step3Add_moistValve_open_percentage                                   |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step3Add_moist_status                                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step3Alarm_after_step                                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step3Grill_intensity                                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step3Pause_after_step                                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step3Remove_moistStart_at_minute                                      |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step3_Steam_assist                                                    |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step3_Steam_assistSet_time_in_minutes                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step3_Steam_assist_intensity                                          |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step3_duration                                                        |                   |                      |                     |                     |                        |                        | 30                  |                      |                                     |                           |                                  |                  |
| statusList.Step3_heater_system                                                   |                   |                      |                     |                     |                        |                        | 3110                |                      |                                     |                           |                                  |                  |
| statusList.Step3_remaining_time                                                  |                   |                      |                     |                     |                        |                        | 1                   |                      |                                     |                           |                                  |                  |
| statusList.Step3_setMulti_level_baking                                           |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step3_set_temperature                                                 |                   |                      |                     |                     |                        |                        | 100                 |                      |                                     |                           |                                  |                  |
| statusList.Step3_status                                                          |                   |                      |                     |                     |                        |                        | 0                   |                      |                                     |                           |                                  |                  |
| statusList.Step4Add_moistStart_at_minute                                         |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step4Add_moistValve_open_percentage                                   |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step4Add_moist_status                                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step4Alarm_after_step                                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step4Grill_intensity                                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step4Pause_after_step                                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step4Remove_moistStart_at_minute                                      |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step4Steam_assist                                                     |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step4Steam_assistSet_time_in_minutes                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step4Steam_assist_intensity                                           |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step4_bake_mode                                                       |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step4_duration                                                        |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step4_passed_time                                                     |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step4_remaining_time                                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step4_setMulti_level_baking                                           |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step4_set_heater_system                                               |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step4_set_microwave_wattage                                           |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step4_set_temperature                                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step4_status                                                          |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step4_steam_available                                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step4_time_unit                                                       |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step5Add_moistStart_at_minute                                         |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step5Add_moistValve_open_percentage                                   |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step5Add_moist_status                                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step5Alarm_after_step                                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step5Grill_intensity                                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step5Pause_after_step                                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step5Remove_moistStart_at_minute                                      |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step5Steam_assist                                                     |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step5Steam_assistSet_time_in_minutes                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step5Steam_assist_intensity                                           |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step5_bake_mode                                                       |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step5_duration                                                        |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step5_passed_time                                                     |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step5_remaining_time                                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step5_setMulti_level_baking                                           |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step5_set_heater_system                                               |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step5_set_microwave_wattage                                           |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step5_set_temperature                                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step5_status                                                          |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step5_steam_available                                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step5_time_unit                                                       |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_1_bake_mode                                                      |                   |                      |                     |                     |                        |                        |                     | 3                    |                                     |                           |                                  |                  |
| statusList.Step_1_duration                                                       |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_1_fastpreheat_function                                           |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_1_passed_time                                                    |                   |                      |                     |                     |                        |                        |                     | 16777215             |                                     |                           |                                  |                  |
| statusList.Step_1_remaining_time                                                 |                   |                      |                     |                     |                        |                        |                     | 16777215             |                                     |                           |                                  |                  |
| statusList.Step_1_set_heater_system                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_1_set_microwave_wattage                                          |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_1_set_temperature                                                |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_1_status                                                         |                   |                      |                     |                     |                        |                        |                     | 1                    |                                     |                           |                                  |                  |
| statusList.Step_1_steam_available                                                |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_1_time_unit                                                      |                   |                      |                     |                     |                        |                        |                     | 2                    |                                     |                           |                                  |                  |
| statusList.Step_2_bake_mode                                                      |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_2_duration                                                       |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_2_passed_time                                                    |                   |                      |                     |                     |                        |                        |                     | 16777215             |                                     |                           |                                  |                  |
| statusList.Step_2_remaining_time                                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_2_set_heater_system                                              |                   |                      |                     |                     |                        |                        |                     | 66                   |                                     |                           |                                  |                  |
| statusList.Step_2_set_microwave_wattage                                          |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_2_set_temperature                                                |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_2_status                                                         |                   |                      |                     |                     |                        |                        |                     | 2                    |                                     |                           |                                  |                  |
| statusList.Step_2_steam_available                                                |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_2_time_unit                                                      |                   |                      |                     |                     |                        |                        |                     | 2                    |                                     |                           |                                  |                  |
| statusList.Step_3_bake_mode                                                      |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_3_duration                                                       |                   |                      |                     |                     |                        |                        |                     | 16777215             |                                     |                           |                                  |                  |
| statusList.Step_3_passed_time                                                    |                   |                      |                     |                     |                        |                        |                     | 16777215             |                                     |                           |                                  |                  |
| statusList.Step_3_remaining_time                                                 |                   |                      |                     |                     |                        |                        |                     | 16777215             |                                     |                           |                                  |                  |
| statusList.Step_3_set_heater_system                                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_3_set_microwave_wattage                                          |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_3_set_temperature                                                |                   |                      |                     |                     |                        |                        |                     | 65535                |                                     |                           |                                  |                  |
| statusList.Step_3_status                                                         |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_3_steam_available                                                |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_3_time_unit                                                      |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_after_bakeAdd_moistStart_at_minute                               |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_after_bakeAdd_moistValve_open_percentage                         |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_after_bakeAdd_moist_status                                       |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_after_bakeRemove_moistStart_at_minute                            |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_after_bake_duration                                              |                   |                      |                     |                     |                        |                        |                     | 16777215             |                                     |                           |                                  |                  |
| statusList.Step_after_bake_mode                                                  |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_after_bake_passed_time                                           |                   |                      |                     |                     |                        |                        |                     | 16777215             |                                     |                           |                                  |                  |
| statusList.Step_after_bake_remaining_Time                                        |                   |                      |                     |                     |                        |                        |                     | 16777215             |                                     |                           |                                  |                  |
| statusList.Step_after_bake_setMulti_level_baking                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_after_bake_set_heater_system                                     |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_after_bake_set_temperature                                       |                   |                      |                     |                     |                        |                        |                     | 65535                |                                     |                           |                                  |                  |
| statusList.Step_after_bake_status                                                |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_after_bake_time_unit                                             |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_pre_bakeAdd_moistStart_at_minute                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_pre_bakeAdd_moistValve_open_percentage                           |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_pre_bakeAdd_moist_status                                         |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_pre_bakeRemove_moistStart_at_minute                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_pre_bake_duration                                                |                   |                      |                     |                     |                        |                        |                     | 16777215             |                                     |                           |                                  |                  |
| statusList.Step_pre_bake_mode                                                    |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_pre_bake_passed_time                                             |                   |                      |                     |                     |                        |                        |                     | 16777215             |                                     |                           |                                  |                  |
| statusList.Step_pre_bake_remaining_time                                          |                   |                      |                     |                     |                        |                        |                     | 16777215             |                                     |                           |                                  |                  |
| statusList.Step_pre_bake_setMulti_level_baking                                   |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_pre_bake_set_heater_system                                       |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_pre_bake_set_temperature                                         |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Step_pre_bake_status                                                  |                   |                      |                     |                     |                        |                        |                     | 1                    |                                     |                           |                                  |                  |
| statusList.Step_pre_bake_time_unit                                               |                   |                      |                     |                     |                        |                        |                     | 2                    |                                     |                           |                                  |                  |
| statusList.StopAddGoAllowed                                                      |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 2                         |                                  |                  |
| statusList.Stopaddgo_status                                                      |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 1                         |                                  |                  |
| statusList.Storage_mode_allowed                                                  | 1                 | 2                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Storage_mode_on_demand_stat                                           | 0                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.SummerWinter_timeAutomatic_setting                                    |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Super_rinse_on_demand                                                 | 0                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Super_rinse_on_demand_allowed                                         | 0                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Super_rinse_setting_status                                            | 1                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Super_rinse_status                                                    | 0                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Synchro_Start_Level                                                   |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Synchro_Stop_Level                                                    |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Tab_setting_status                                                    | 1                 | 1                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.TemperatureSensor1                                                    |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.TemperatureSensor2                                                    |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 30                               |                  |
| statusList.TemperatureUnit                                                       |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.Temperature_reached_notification_setting                              |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Temperature_unit_setting_status                                       |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Temperature_unit_status                                               | 1                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.TemporaryLanguageSelected                                             |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           | 16                               |                  |
| statusList.TemporaryLanguageSettingEnabled                                       |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           | 1                                |                  |
| statusList.Test_mode                                                             |                   |                      |                     |                     | 0                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Text_size_setting                                                     |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.TimeDateAutomatic_setting                                             |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.TimeIconSetting                                                       |                   |                      |                     |                     |                        |                        |                     |                      | 1                                   |                           | 1                                |                  |
| statusList.TimeRemaining                                                         |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.Time_format                                                           |                   |                      |                     |                     |                        |                        |                     | 2                    |                                     |                           |                                  |                  |
| statusList.Time_program_Set_time_status                                          |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Time_program_set_duration_status                                      | 0                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Time_save_status                                                      |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Time_zone_setting                                                     |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.TimerEndTime                                                          |                   |                      | 0002/11/30T00:00:00 |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.TimerPausedTime                                                       |                   |                      | 0002/11/30T00:00:00 |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.TimerPausedTotalSeconds                                               |                   |                      | 0                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.TimerStartTime                                                        |                   |                      | 0002/11/30T00:00:00 |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.TimerStatus                                                           |                   |                      | 1                   |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Timer_status                                                          |                   |                      |                     | 6201                |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.TotalProgramCycles                                                    |                   |                      |                     |                     |                        |                        |                     |                      | 17                                  |                           |                                  |                  |
| statusList.TotalProgramsCycles                                                   |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 323                              |                  |
| statusList.Total_duration_in_seconds                                             |                   |                      |                     |                     |                        |                        |                     | 16777215             |                                     |                           |                                  |                  |
| statusList.Total_energy_consumption                                              | 443               | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Total_number_of_cycles                                                | 483               | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Total_oven_usage_value                                                |                   |                      |                     |                     |                        |                        |                     | 65535                |                                     |                           |                                  |                  |
| statusList.Total_passed_time                                                     |                   |                      |                     |                     |                        |                        | 2                   |                      |                                     |                           |                                  |                  |
| statusList.Total_passed_time_seconds                                             |                   |                      |                     |                     |                        |                        |                     | 16777215             |                                     |                           |                                  |                  |
| statusList.Total_remaining_time                                                  |                   |                      |                     |                     |                        |                        | 0                   |                      |                                     |                           |                                  |                  |
| statusList.Total_remaining_time_seconds                                          |                   |                      |                     |                     |                        |                        |                     | 16777215             |                                     |                           |                                  |                  |
| statusList.Total_run_time                                                        | 1101              | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Total_time_of_cooking_in_hours                                        |                   |                      |                     |                     |                        | 491                    |                     |                      |                                     |                           |                                  |                  |
| statusList.Total_time_of_cooking_in_minute                                       |                   |                      |                     |                     | 1629                   |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Total_water_consumption                                               | 5362              | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Turbidity_sensor_setting_status                                       |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 3                         |                                  |                  |
| statusList.UTC_dateTime_BDC_timer_end_time_timestamp                             |                   |                      |                     | 2024/03/17T20:29:56 |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.UTC_dateTime_BDC_timer_start_time_timestamp                           |                   |                      |                     | 2024/03/17T20:19:56 |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.UV_mode_on_demand                                                     | 2                 | 2                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.UV_mode_on_demand_allowed                                             | 3                 | 3                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Units_setting_status                                                  |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 3                         |                                  |                  |
| statusList.View_size_setting_status                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Volume                                                                |                   |                      |                     |                     |                        |                        |                     | 4                    | 0                                   |                           | 3                                |                  |
| statusList.Volume_setting                                                        |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     | 25                        |                                  |                  |
| statusList.Warming_drawer_power_level                                            |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Warming_drawer_status                                                 |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Water_consumption_in_running_program                                  | 65535             | 65535                |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Water_hardness                                                        |                   |                      |                     |                     |                        |                        |                     | 3                    |                                     |                           |                                  |                  |
| statusList.Water_hardness_setting_status                                         | 1                 | 5                    |                     |                     |                        |                        |                     |                      |                                     | 2                         |                                  |                  |
| statusList.Water_inlet_setting_status                                            | 0                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Water_save_setting_status                                             | 0                 | 0                    |                     |                     |                        |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Water_tank                                                            | 0                 | 0                    |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Water_tank_level                                                      |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Weight_unit_setting                                                   |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Weight_unit_setting_status                                            |                   |                      |                     |                     |                        |                        |                     |                      |                                     | 0                         |                                  |                  |
| statusList.Welcome                                                               |                   |                      |                     |                     |                        |                        |                     | 0                    |                                     |                           |                                  |                  |
| statusList.Window_status                                                         |                   |                      |                     |                     | 1                      |                        |                     |                      |                                     |                           |                                  |                  |
| statusList.Zone_number                                                           |                   |                      |                     |                     |                        | 5                      |                     |                      |                                     |                           |                                  |                  |
| statusList.daily_energy_kwh                                                      | 0                 | 0                    | 0                   | 0                   | 0                      | 0                      | 0                   | 0                    | 0                                   | 0                         | 0                                | 0                |
| statusList.f_backwater                                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 0                |
| statusList.f_e_clockchip_fault                                                   |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 0                |
| statusList.f_e_coiltemp                                                          |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 0                |
| statusList.f_e_displaycom_fault                                                  |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 0                |
| statusList.f_e_downwatertank_fault                                               |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 0                |
| statusList.f_e_drive_fault                                                       |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 0                |
| statusList.f_e_drivecom_fault                                                    |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 0                |
| statusList.f_e_e2data_fault                                                      |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 0                |
| statusList.f_e_eanode_fault                                                      |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 0                |
| statusList.f_e_env_temp                                                          |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 0                |
| statusList.f_e_exhaust                                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 0                |
| statusList.f_e_fan_fault                                                         |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 0                |
| statusList.f_e_powermodule_fault                                                 |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 0                |
| statusList.f_e_push                                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 0                |
| statusList.f_e_returnwatertemp_fault                                             |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 0                |
| statusList.f_e_solar_temperature                                                 |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 0                |
| statusList.f_e_suctiontemp_fault                                                 |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 0                |
| statusList.f_e_upwatertank_fault                                                 |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 0                |
| statusList.f_electric_heating                                                    |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 0                |
| statusList.f_electricity                                                         |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 0                |
| statusList.f_heat_pump                                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 1                |
| statusList.f_power_consumption                                                   |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 0                |
| statusList.f_sterilization                                                       |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 1                |
| statusList.f_votage                                                              |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 0                |
| statusList.f_water_tank_temp                                                     |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 60               |
| statusList.oem_host_version                                                      |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | S1798.6.01.06.RB |
| statusList.reserved1                                                             |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.reserved105                                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.reserved106                                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.reserved107                                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.reserved110                                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.reserved111                                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.reserved112                                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.reserved113                                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.reserved114                                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.reserved115                                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.reserved116                                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.reserved117                                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.reserved118                                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.reserved125                                                           |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.reserved128                                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.reserved129                                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.reserved130                                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.reserved14                                                            |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.reserved18                                                            |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.reserved2                                                             |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.reserved20                                                            |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.reserved3                                                             |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.reserved4                                                             |                   |                      |                     |                     |                        |                        |                     |                      | 0                                   |                           |                                  |                  |
| statusList.reserved8                                                             |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.reserved83                                                            |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.reserved9                                                             |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           | 0                                |                  |
| statusList.t_air                                                                 |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 0                |
| statusList.t_backwater_set                                                       |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 0                |
| statusList.t_beep                                                                |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 0                |
| statusList.t_fan_speed                                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 0                |
| statusList.t_power                                                               |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 1                |
| statusList.t_sterilization                                                       |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 0                |
| statusList.t_temp                                                                |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 35               |
| statusList.t_vacation                                                            |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 0                |
| statusList.t_vacation_timeleft                                                   |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 0                |
| statusList.t_vacation_timeset                                                    |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 1                |
| statusList.t_work_mode                                                           |                   |                      |                     |                     |                        |                        |                     |                      |                                     |                           |                                  | 9                |
| useTime                                                                          | 1690885767539     | 1710363016020        | 0                   | 0                   | 0                      | 0                      | 0                   | 0                    | 0                                   | 0                         | 0                                | 0                |
| wifiId                                                                           | <redacted>        | <redacted>           | <redacted>          | <redacted>          | <redacted>             | <redacted>             | <redacted>          | <redacted>           | <redacted>                          | <redacted>                | <redacted>                       | <redacted>       |

## Generated from

- [Asko_dishwasher](Asko_dishwasher.json)
- [Gorenje_dishwasher](Gorenje_dishwasher.json)
- [Asko_hood_1](Asko_hood_1.json)
- [Asko_hood_2](Asko_hood_2.json)
- [Asko_induction_hob_1](Asko_induction_hob_1.json)
- [Asko_induction_hob_2](Asko_induction_hob_2.json)
- [Oven_type_1](Oven_type_1.json)
- [Oven_type_2](Oven_type_2.json)
- [Asko_professional_washing_machine](Asko_professional_washing_machine.json)
- [Gorenje_washing_machine](Gorenje_washing_machine.json)
- [Asko_professional_tumble_dryer](Asko_professional_tumble_dryer.json)
- [Heat_pump](Heat_pump.json)
